@@ -1,8 +1,8 @@
 package Poet::Cache;
 BEGIN {
-  $Poet::Cache::VERSION = '0.10';
+  $Poet::Cache::VERSION = '0.11';
 }
-use Poet qw($conf $env);
+use Poet qw($conf $poet);
 use Method::Signatures::Simple;
 use Moose;
 
@@ -10,7 +10,7 @@ extends 'CHI';
 
 method initialize_caching () {
     my $default_config =
-      { defaults => { driver => 'File', root_dir => $env->data_path("cache") }
+      { defaults => { driver => 'File', root_dir => $poet->data_path("cache") }
       };
     my $config = $conf->get_hash( 'cache' => $default_config );
     __PACKAGE__->config($config);
