@@ -1,9 +1,9 @@
 package Poet::Mason::Plugin::Request;
 BEGIN {
-  $Poet::Mason::Plugin::Request::VERSION = '0.10';
+  $Poet::Mason::Plugin::Request::VERSION = '0.11';
 }
 use Mason::PluginRole;
-use Poet qw($conf $env);
+use Poet qw($conf $poet);
 use Poet::Plack::Response;
 use JSON::XS;
 use Try::Tiny;
@@ -12,7 +12,7 @@ has 'req' => ( is => 'ro', required => 1, isa => 'Object' );
 has 'res' => ( is => 'ro', lazy_build => 1 );
 
 method _build_res () {
-    return $env->app_class('Plack::Response')->new();
+    return $poet->app_class('Plack::Response')->new();
 }
 
 around 'run' => sub {
