@@ -1,6 +1,6 @@
 package Poet::Mechanize;
 BEGIN {
-  $Poet::Mechanize::VERSION = '0.10';
+  $Poet::Mechanize::VERSION = '0.11';
 }
 use Poet::Environment;
 use Plack::Util;
@@ -8,8 +8,8 @@ use base qw(Test::WWW::Mechanize::PSGI);
 
 sub new {
     my ( $class, %params ) = @_;
-    my $env = delete( $params{'env'} ) || Poet::Environment->current_env;
-    my $app = Plack::Util::load_psgi( $env->bin_path("app.psgi") );
+    my $poet = delete( $params{'env'} ) || Poet::Environment->current_env;
+    my $app = Plack::Util::load_psgi( $poet->bin_path("app.psgi") );
     return $class->SUPER::new( app => $app, %params );
 }
 
