@@ -1,6 +1,6 @@
 package Poet::Script;
 BEGIN {
-  $Poet::Script::VERSION = '0.10';
+  $Poet::Script::VERSION = '0.11';
 }
 use Cwd qw(realpath);
 use File::Basename;
@@ -14,7 +14,7 @@ use warnings;
 method import ($pkg:) {
     unless ( Poet::Environment->current_env ) {
         my $root_dir = determine_root_dir();
-        my $env      = initialize_with_root_dir($root_dir);
+        my $poet     = initialize_with_root_dir($root_dir);
     }
     Poet::Environment->current_env->importer->export_to_level( 1, @_ );
 }
@@ -69,7 +69,7 @@ Poet::Script -- Intialize Poet for a script
 =head1 SYNOPSIS
 
     # In a script...
-    use Poet::Script qw($cache $conf $env $log :file);
+    use Poet::Script qw($cache $conf $poet $log :file);
 
 =head1 DESCRIPTION
 
