@@ -1,6 +1,6 @@
 package Poet::Test::Class;
 BEGIN {
-  $Poet::Test::Class::VERSION = '0.10';
+  $Poet::Test::Class::VERSION = '0.11';
 }
 use Method::Signatures::Simple;
 use Carp;
@@ -73,8 +73,8 @@ method share_dir () {
 }
 
 method initialize_temp_env ($class:) {
-    my $env = $class->temp_env(@_);
-    Poet::Environment->initialize_current_environment( env => $env );
+    my $poet = $class->temp_env(@_);
+    Poet::Environment->initialize_current_environment( env => $poet );
 }
 
 method mech ($class:) {
