@@ -1,6 +1,6 @@
 package Poet::t::Import;
 BEGIN {
-  $Poet::t::Import::VERSION = '0.10';
+  $Poet::t::Import::VERSION = '0.11';
 }
 use Test::Class::Most parent => 'Poet::Test::Class';
 
@@ -12,20 +12,37 @@ BEGIN {
 }
 
 sub test_valid_vars : Tests {
-    cmp_deeply( $importer->valid_vars, supersetof(qw(cache conf env log)) );
+    cmp_deeply( $importer->valid_vars, supersetof(qw(cache conf log poet)) );
 }
 
 sub test_import_vars : Tests {
     {
         package TestImportVars;
 BEGIN {
-  $TestImportVars::VERSION = '0.10';
+  $TestImportVars::VERSION = '0.11';
 }
-        BEGIN { $importer->export_to_level( 0, qw($cache $conf $env) ) }
+        BEGIN { $importer->export_to_level( 0, qw($cache $conf $env $poet) ) }
         use Test::Most;
         isa_ok( $cache, 'CHI::Driver',       '$cache' );
         isa_ok( $conf,  'Poet::Conf',        '$conf' );
         isa_ok( $env,   'Poet::Environment', '$env' );
+        isa_ok( $poet,  'Poet::Environment', '$poet' );
+        is( $env, $poet, '$env/$poet backward compat' );
+    }
+}
+
+sub test_import_bad_vars : Tests {
+    {
+        package TestImportVars2;
+BEGIN {
+  $TestImportVars2::VERSION = '0.11';
+}
+        use Test::Most;
+        throws_ok(
+            sub { $importer->export_to_level( 0, qw($bad) ) },
+            qr/unknown import var '\$bad': valid import vars are '\$cache', '\$conf', '\$log', '\$poet'/,
+            'bad import'
+        );
     }
 }
 
@@ -33,7 +50,7 @@ sub test_import_methods : Tests {
     {
         package TestImportMethods1;
 BEGIN {
-  $TestImportMethods1::VERSION = '0.10';
+  $TestImportMethods1::VERSION = '0.11';
 }
         BEGIN { $importer->export_to_level(0) }
         use Test::Most;
@@ -43,7 +60,7 @@ BEGIN {
     {
         package TestImportMethods2;
 BEGIN {
-  $TestImportMethods2::VERSION = '0.10';
+  $TestImportMethods2::VERSION = '0.11';
 }
         BEGIN { $importer->export_to_level( 0, qw(:file) ) }
         use Test::Most;
@@ -54,7 +71,7 @@ BEGIN {
     {
         package TestImportMethods3;
 BEGIN {
-  $TestImportMethods3::VERSION = '0.10';
+  $TestImportMethods3::VERSION = '0.11';
 }
         BEGIN { $importer->export_to_level( 0, qw(:web) ) }
         use Test::Most;
