@@ -1,6 +1,6 @@
 package Poet::t::Log;
 BEGIN {
-  $Poet::t::Log::VERSION = '0.10';
+  $Poet::t::Log::VERSION = '0.11';
 }
 use Poet::Tools qw(tempdir_simple);
 use File::Path qw(rmtree);
@@ -10,9 +10,9 @@ use Test::Class::Most parent => 'Poet::Test::Class';
 __PACKAGE__->initialize_temp_env();
 
 sub test_log_config : Tests {
-    my $env       = Poet::Environment->current_env;
-    my $conf      = $env->conf;
-    my $logs_dir  = $env->logs_dir;
+    my $poet      = Poet::Environment->current_env;
+    my $conf      = $poet->conf;
+    my $logs_dir  = $poet->logs_dir;
     my $temp_dir  = tempdir_simple();
     my $other_dir = "$temp_dir/other";
 
